1;
__END__

=pod

=encoding Shift_JIS

=head1 \tgEFA

Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese document)

=head1 Tv

   g: A

    XNvg ShiftJIS_script.pl ̒ɈȉLq...
      use Sjis;
      use Sjis version;          --- Sjis.pm ̃o[W`FbNsꍇ
      use Sjis qw(ord reverse);  --- ord, reverse ̊g@\gꍇ
      use Sjis version qw(ord reverse);

       no Sjis; ͗pł܂B

      g֐
        Sjis::ord(...);
        Sjis::reverse(...);
        Sjis::length(...);
        Sjis::substr(...);
        Sjis::index(...);
        Sjis::rindex(...);

    R}hvvgňȉ̂悤Ɏs
      perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
      perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
      perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
      perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
      perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...

      ? * găChJ[h̎w肪ł܂
      ' ` ' găNH[g邱Ƃł܂

   g: B

    R}hvvgňȉ̂悤Ɏs

      C:\>perl  Sjis.pm  ShiftJIS_script.pl  >  Escaped_script.pl.e
      C:\>perl  Escaped_script.pl.e

      ShiftJIS_script.pl  --- ShiftJIS ŏꂽXNvg
      Escaped_script.pl.e --- GXP[vꂽXNvg

=head1 v

܂ł̗j͂߂܂傤BShiftJIS ̃T|[g jperl 4.019+1.3 n
܂܂Bɂ chop() Ȃǂ̊֐␳K\𕡎Gȓ{̕ɑ΂
Kpł悤ɂȂ܂B

Perl5.8 ȍ~ Encode W[ɂă}`KT|[gꂽ߁A
jperl ͕svɂȂƌĂ܂BłA͖{Ȃ̂ł傤H

{ɂāAėp^Rs[^̓óAp[\iRs[^̓R[
hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B̂
UTF8 tO͂܂B

ȂGR[h̖肩GXP[v܂񂩁H

=head1 ЂƂ̖

JPerl ͂ƂĂDꂽ\tgEFAłBƁAł JPerl ͓{Ήł
Perl ̂ƂŁAJava  JVM Ƃ͊֌W܂BȂ킯ŁÃ\tgEFA
͏Փˉ̂߂ Sjis ƂOɂ܂B

ƂŁA JPerl ̓o[W 5.005_04 ȍ~AeiXĂ܂B

ώcOȂƂɁAJPerl̊Jsn  The Perl Confernce Japan
1998 ɂ

  "킽Ȃׂ͔ꂽ玟̐l낵"

ƂbZ[WcAPerl 痣ĂĂ܂܂B

XCh15 "jperl ̍"

ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt

ƒNpŏĂ邾낤B
ȂǂƊ҂Ȃ10NԁA҂ԂɐE͈ႤւƐił̂łB

̃\tgEFA ShiftJIS ŏꂽ Perl XNvgGXP[v邽߂
\[XR[htB^łBGXP[vɂĕR[hω邱Ƃ͂
܂B

̃\tgEFA͈ȉ̓܂B

=over 2

=item * ShiftJIS ̂܂܂̒l

=item * ߋ̃f[^AXNvgAmEnEƌ݊ۂĂ

=item * UTF8 tOȂł(perlunitut  perluniadvice ̑Ή͕sv)

=item * (JPerlێ炷邽߂) C vO~OsȂł

=item * (CPU, OS, perl̃o[W, 32rbg/64rbgł̈Ⴂɂ) oCit@CɈˑȂ

=back

AJPerl ̖ɂĂЂƂ̖܂傤B

=head1 {IȎdg

ŋ߁Aȉ̃[Ĕ܂B

[Tokyo.pm] jus Benkyoukai

http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html

("SJIS.pm" Ƃt@CŕۑĂ̂Ƃ܂)

  package SJIS;
  use Filter::Util::Call;
  sub multibyte_filter {
      my $status;
      if (($status = filter_read()) > 0 ) {
          s/([\x81-\x9f\xe0-\xef])([\x40-\x7e\x80-\xfc])/
              sprintf("\\x%02x\\x%02x",ord($1),ord($2))
          /eg;
      }
      $status;
  }
  sub import {
      filter_add(\&multibyte_filter);
  }
  1;

{Iɂ́Ã\tgEFA͏L̂悤ȂƂs܂B
AFilter::Util::Call 𗘗pĂȂ_APerl ̍\͂ĕKvɉ
GXP[v_قȂ܂B

=head1 CXg[@

   perl Makefile.pl         --- Makefile.pl  make.bat 𐶐܂
   make.bat install
   make.bat test

   make.bat install         --- ݎgp perl ɃCXg[܂
   perl58 make.bat install  --- perl5.008 ɃCXg[܂
   perl510 make.bat install --- perl5.010 ɃCXg[܂
   perl512 make.bat install --- perl5.012 ɃCXg[܂
   perl64  make.bat install --- perl64    ɃCXg[܂

   make.bat dist            --- CPAN zzppbP[W܂
   make.bat tar.bat         --- tar.bat 쐬܂

=head1 \tgEFÄꗗ

   Sjis.pm          --- ShiftJIS \[XR[htB^W[
   Esjis.pm         --- Sjis.pm ̃^C[`
   perl58.bat       --- ϐ PATH ̐ݒȂ perl5.8  TĎs
   perl510.bat      --- ϐ PATH ̐ݒȂ perl5.10 TĎs
   perl512.bat      --- ϐ PATH ̐ݒȂ perl5.12 TĎs
   perl64.bat       --- ϐ PATH ̐ݒȂ perl64   TĎs

=head1 NX̒`

ߋperlƂ̌݊ۂ߂ɕNX͈ȉ̂悤ɍĒ`Ă܂B

  ---------------------------------------------------------------------------
  escape        class
  ---------------------------------------------------------------------------
  \d            [0-9]
  \s            [\x09\x0A\x0C\x0D\x20]
  \w            [0-9A-Z_a-z]
  \D            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9])
  \S            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x09\x0A\x0C\x0D\x20])
  \W            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z])
  \h            [\x09\x20]
  \v            [\x0C\x0A\x0D]
  \H            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x09\x20])
  \V            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x0C\x0A\x0D])
  ---------------------------------------------------------------------------

=head1 JPerl ݊̋@\

ȉ̊֐ JPerl Ɠlɋ@\܂B
̃\tgEFAɂď֐܂B

=over 2

=item * VONH[g2INebgR[ḧ

=item * _uNH[g2INebgR[ḧ

=item * VONH[g2INebgR[hK\̈

=item * _uNH[g2INebgR[hK\̈

=item * chop  Esjis::chop ɏ܂

=item * split  Esjis::split ɏ܂

=item * length ͂̂܂܂ł

=item * substr ͂̂܂܂ł

=item * index  Esjis::index ɏ܂

=item * rindex  Esjis::rindex ɏ܂

=item * pos ͂̂܂܂ł

=item * lc  Esjis::lc ܂ Esjis::lc_ ɏ܂

=item * uc  Esjis::uc ܂ Esjis::uc_ ɏ܂

=item * ord ͂̂܂܂ł(C|[gȂꍇ)

=item * reverse ͂̂܂܂ł(C|[gȂꍇ)

=item * tr/// ܂ y///  Esjis::tr ɏ܂

    /b  /B Cqpł܂B

=item * chdir  Esjis::chdir ɏ܂

    MSWin32 ̏ꍇ perl5.005 Ɍ蕶R[h(0x5C)ŏIpX
    ł܂B

=item * do file  Esjis::do file ɏ܂

=item * require  Esjis::require ɏ܂

=item * use Perl::Module @list; 

    BEGIN { Esjis::require 'Perl/Module.pm'; Perl::Module->import(@list); } 
    ܂B

=item * use Perl::Module (); 

    BEGIN { Esjis::require 'Perl/Module.pm'; } ɏ܂B

=back

=head1 JPerl Əʌ݊̋@\

ȉ̋@\ JPerl Əʌ݊łB

=over 2

=item * chr  Esjis::chr ܂ Esjis::chr_ ɏ܂

    2INebgR[hɑΉĂ܂B

=item * -X (t@CeXgZq)  Esjis::X ܂ Esjis::X_ ɏ܂

    ႦΓǎ\ǂeXg -r  Esjis::r ɂȂ܂B

    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=item * glob  Esjis::glob ܂ Esjis::glob_ ɏ܂

    @glob = Esjis::glob($string);
    @glob = Esjis::glob_;

    Esjis::glob ́AOSԂŉ̂gꂽDOSOu(ChJ[h)
    @\񋟂܂BfBNgpXɂChJ[hgpłA啶
    ̋ʂȂAtXbVƃXbVgpł܂(
    tXbV2dɂȂ΂Ȃ܂)B

    s@́A

    use Sjis;
    @perlfiles = glob  "..\pe?l/*.p?";
    print <..\pe?l/*.p?>;

    "~" ݂͌̃[Ũz[fBNgɓWJ܂B
    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=item * lstat  Esjis::lstat ܂ Esjis::lstat_ ɏ܂

    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=item * opendir  Esjis::opendir ɏ܂

    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=item * stat  Esjis::stat ܂ Esjis::stat_ ɏ܂

    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=item * unlink  Esjis::unlink ɏ܂

    MSWin32 ɂĕR[h(0x5C)ŏIpXƂł܂B

=back

=head1 ẘ֐

=item * ord  Sjis::ord ܂ Sjis::ord_ ɏ܂

    "use Sjis qw(ord);" ɂ ord  Sjis::ord ɏ悤ɂȂ܂B

    $ord = Sjis::ord($string);

    Sjis::ord($string)  $string ̐擪̕ ShiftJIS R[hlԂ܂B
    $string ȗꂽꍇ $_ ΏۂƂȂ܂B̊֐͏ɕȂ
    lԂ܂B

    ̓ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂݋@\悤
    ȂĂ܂B

=item * reverse  Sjis::reverse ɏ܂

    "use Sjis qw(reverse);" ɂ reverse  Sjis::reverse ɏ悤
    ɂȂ܂B

    @reverse = Sjis::reverse(@list);
    $reverse = Sjis::reverse(@list);

    Sjis::reverse(@list) ̓XgReLXgł @list ̗vftɕׂ
    XglԂ܂B
    𗘗pāA~̐𔭐邱Ƃł܂B

    for (Sjis::reverse(1 .. 10)) { ... }

    @list ƂănbVnꍇÃnbV̓tbgȃXgɕϊ
    B̂Ƃ𗘗p΁Areverse gănbVtɂ(lL[
    Ђ悤ɂ)Ƃł܂(AׂĂ̒lj[Nł邱ƂO
    ł)B

    %barfoo = Sjis::reverse(%foobar);

    XJ[ReLXgł @list ׂ̂Ă̗vfAŁAShiftJIS 
    Pʂŋtɂ̂Ԃ܂B

    ̓ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂݋@\悤
    ȂĂ܂B

=item * Sjis::length

    $length = Sjis::length($string);
    $length = Sjis::length();

    Sjis::length($string) ̓XJ[l $string ̒ ShiftJIS ̕ŕ
    ܂B$string ȗꍇ $_ ̕Ԃ܂B

    ̒APʂł͂ȂAoCgPʂŐɂ

    $blen = length $string;

    邢

    $blen = CORE::length $string;

    Ƃ܂B

=item * Sjis::substr

    $substr = Sjis::substr($string,$offset,$length,$replacement);
    $substr = Sjis::substr($string,$offset,$length);
    $substr = Sjis::substr($string,$offset);

    Sjis::substr ́AShiftJIS  $string Ŏw肳ꂽ񂩂畔
    oĕԂ܂B́A̐擪琔 $offset ڂn܂A
    $length łB$offset Ȃ΁A̖ -$offset ߂
    Ƃ납畔񂪊Jn܂B$length ȗƁA̖܂łׂĂ
    Ԃ܂B$length Ȃ΁A̖ -$length c悤ɁA
    ߂܂BłȂ΁A$length ́AȂ҂悤ɁAo
    ̒\Ă܂B

    Sjis::substr Ӓl(̑ΏۂƂȂ)ƂĎgƂ͂ł܂B̑
    ɁA4 $replacement ɒup̕w肵܂B̏ꍇA
    Sjis::substr  $string ̈ꕔ𕶎 $replacement ŒuƂƂɁA
    (splice ̂悤)uꂽlƂĕԂ܂B̗́A$var ̍Ō
     "Curly" ŒuƂƂɁAuꂽ $oldstr ɃZbg
    :

    $oldstr = Sjis::substr($var, -1, 1, "Curly");

    $var ̐擪ɕ "Larry" tɂ́Â悤ɂ܂:

    Sjis::substr($var, 0, 0, "Larry");

    $var ̍ŏ1 "Moe" Œuɂ́Â悤ɂ܂:

    Sjis::substr($var, 0, 1, "Moe");

    $var ̍Ō1 "Curly" Œuɂ͎̂悤ɂ܂:

    Sjis::substr($var, -1, 1, "Curly");

=item * Sjis::index

    $index = Sjis::index($string,$substring,$start);
    $index = Sjis::index($string,$substring);

    Sjis::index ́AShiftJIS  $string ̒Ɋ܂܂A1 ShiftJIS 
     $substr T܂B$string ̒ŁA$substr ŏɏoʒu𕶎P
    ŐĕԂ܂B$start w肳ĂꍇA$string ̐擪 $start 
    XLbvʒuA$substr Tn߂܂Bʒu 0 x[XɂƂ
    ܂B$substr Ȃ΁ASjis::index ֐̓x[X 1 
    l -1 Ԃ܂BSjis::index gāAŜ𒲂ׂɂ́Â悤ɂ
    ܂B

    $pos = -1;
    while (($pos = Sjis::index($string, $lookfor, $pos)) > -1) {
        print "Found at $pos\n";
        $pos++;
    }

=item * Sjis::rindex

    $rindex = Sjis::rindex($string,$substring,$position);
    $rindex = Sjis::rindex($string,$substring);

    Sjis::rindex  Sjis::index ƎĂ܂AShiftJIS  $string ̒ŁA
     $substr Ōɏoʒu𕶎PʂŐĕԂ܂(܂
    reverse Sjis::index ł)B$substr Ȃ΁A-1 Ԃ܂B$position
    ɂāAlƂĕԂƂAłËʒuw肷邱Ƃł܂B
    Sjis::rindex gāAŜ𖖔擪ɌĒׂɂ́Â悤
    ɂ܂B

    $pos = Sjis::length($string);
    while (($pos = Sjis::rindex($string, $lookfor, $pos)) >= 0) {
        print "Found at $pos\n";
        $pos--;
    }

=back

=head1 ϐ

 ̃\tgEFA͔r flock ֐gp܂Bt@Cǎ\ɂȂ܂
 邢͏݉\ɂȂ܂ŃvO̎s̓ubN܂B
 ϐ SJIS_NONBLOCK `邱ƂŃubNȂ悤ɂ邱Ƃł
 B

 :

   SET SJIS_NONBLOCK=1

 (l '1' ͈ӖȂ̂ŉł\܂)

=head1 oOƐ

oO񍐁Apb`}܂B

=over 2

=item * format

    IWi Perl Ƌ@\ł(ShiftJIS ɑΉĂ܂)B

=item * chdir

    MSWin32  perl5.006, perl5.008, perl5.010 ɂĕR[h(0x5C)ŏI
    pXƂł܂B

    QlN
    Bug #81839
    chdir does not work with chr(0x5C) at end of path
    http://bugs.activestate.com/show_bug.cgi?id=81839

=item * m/$re/o, s/$re/foo/o, qr/$re/o  /o Cq

    perl5.006 ɂ /o CqҒʂ̓܂łBϐ $re ̒l
    ύXƎ̎sɂ̕ύXf܂B

=item * K\̃GXP[v \b  \B

    K\̃GXP[v \b  \B ͊Ғʂ̋@\܂B

=back

=head1 

̃vWFNg t  ina@cpan.org ɂĎn܂܂B
̃t@C𕪂܂傤B

=head1 쌠

̃\tgEFA̓t[\tgEFAłBȂ Perl ƓCZX
̌ōĔzzyѕύXsƂo܂Bڂ perlartistic QƂ
B

̃\tgEFA͗Lpł邱ƂĔЕz܂A*S̖ۏ* 
łBƉ\̕ۏ؂̖ړIւ̓ḰAOɎꂽ̂
ߑS݂܂B

=head1 VtgJISR[hƂ({񏈗)

VtgJIŚA}CN\tgЂɂJꂽA{̃Rs[^ōł悭
p镄łBVtgJIŚuMS(Microsoft)vA܂́uSJIS
(ShiftJIS̗)vƂĂ΂Ă܂B

ē{̃Rs[^[U͔pЉgȂ߁A]Ƃ̌݊
ێړIŃVtgJISJ܂B

VtgJISɂẮA16i 0x81`0x9F ܂ 0xE0`0xEF ͈̔͂INebg
ɂ12INebg[hJn܂BẴINebǵAn܂
2INebg̑1INebgƂď܂B(2)INebǵA16i
0x40`0x7E ܂ 0x80`0xFC ͈̔͂lłȂ΂Ȃ܂B1INebg
͈͂͊gASCIIZbgA܂ŏʃrbgIɂȂ8rbgZbg͈̔
ɊSɎ܂Ă邱ƂɒڂĂB܂VtgJIŚApЉASCII/JIS
[}T|[gĂ܂B

ꕔ̃VtgJISdl(Ƀ[Jdl)ł́A[U`̃R[ḧAꍇɂ
͔pЉ󔒕̃R[hʒu`Ă܂B{iIȏ]ނ̂
΁Â悤ȃR[ḧR[hʒu͕ssłBƂ̂Â悤ȕ́A
ʂ̓{ꕄ(܂JISEUC)̃R[hʒuɕϊłȂ悤ɕĂ
܂łB

=head1 EBLyfBAɂuShift_JISv̒`

Shift_JIS (2009.09.17 14:00:00 JST). In Wikipedia: The Free Encyclopedia.
Retrieved from
http://ja.wikipedia.org/wiki/Shift_JIS

oT: t[SȎTwEBLyfBA(Wikipedia)x

Shift_JIS(IANAւ̓o^Bǂݕ́wVtgWXx)́Aݑ̃p\R
{\߂ɎgĂ镶R[hłBƎ̃R[hgĂ
A݂͕WĂJIS X 0208̕1ŋK肵ĂB

Microsoft̊ex_Shift_JIS̈ɂẮwMicrosoftR[hy[
W932xQƁBMac OS鈟ɂẮwMacJapanesexQƁB

Shift_JIS̒a
1980NAp\Rp16rbgCPU̕y܂āA\\ȃn[hEF
Ap\RXƔꂽB̂߁Ap\Rp̕
͍ĂB

Shift_JISuVtgJISR[hvƌĂŕW(R[h)̖ʂ݂̂
lc_邪Ał͕̖ʂɏœ_𓖂ĂB

̕ɂ́AsĂ悭pĂJIS C 6220(݂JIS X 0201)
8rbg(ȉupEpJiv)ƁAJIS C 6226(݂JIS X 0208A
ȉuv)̗WA\悤ƂBt@C̑傫AԂ
Zk}邽߃GXP[vV[PXȂō݉\ɂ邱ƂlĂB

JIS C 6220JIS C 62262͂ƂɁAISO 2022ŕW؂ւėp
݌vBISO 2022ɂƂÂł́ApApJiA
ꂼA8rbgԂ̒GL/GRƂ̈1(2)g
Ƃŕ\łBpƊ2GXP[vV[PXȂō݂
ȂApGLAGRɊ蓖Ă@BEUC-JṔA悻̂悤
ɎĂB

Ap\Rł͂łɁAJIS X 02018rbgA܂AGLɉpAGR
PoCgJ^Ji(pJ^Ji)蓖Ă邱ƂyĂBpƂPoC
gJ^Ji2𓮂Ƃ́ǍɂȂ邽ߔKvB
̂߁AISO 2022̘g̗̈Ɋ݂邱Ƃ͍̂łB

1982NA̕ʒu𕡎GɈړ(Vtg)AԂ̌Ԃɉ
ShiftJISaB邽߂ɂ́A1oCgڂƂāAISO 2022
ɂGR(A1(16)-FE(16))̈31cĂgp̈ɂ킦AISO 2022
ɂĔgpCR(80(16)-9F(16))̈gp邱ƂƂBAGL
(21(16)-7E(16))̈ɂẮAJIS X 0201̋Lɓ镔͋ɗ͔B
2oCgڂɂISO 2022Ƃ͈قȂApEpJiɎgpς݂̗̈
܂ށAGLACRAGRɂë̂قڑSĂgKvB

}CN\tg({@l)̌Ð식ɂƁAShift_JIS̐ɂ́AAX
L[A}CN\tg()AOHd@A}CN\tgEFAEA\VGCcA
fW^T[`()ւAɃAXL[̎RǑSƂȂč쐬
̂ƂBɑ΂ِƂāAsẅF́A}CN\t
gEFAEA\VGCcƎOHd@݂̂̋JƎ咣ĂBR{l̔
ɂ͎̓PƂ锭ĂB

Shift_JIS̕W
Shift_JIŚAWƂ̗̕܂ތ̖
邽߂̋ZpłB䂦AJIS X 0208̕W𗘗pĂ͂̂́A
ISO 2022̕̕j͈̔͂̊OɂB

ȂA݂ł́AJIS X 0208:1997̕1ɂāuVtg\vƂ
OŁAdl`ĂB́Aft@NgX^_[hƂȂĂZp
ɂĂ͏oƂAƂWĂ܂ƂӐ}{HƕW
 (JISC) ɂĂ̂ƂłB

JIS X 0208̊gKiłJIS X 0213ł́A2000N̏łŕ1Ƃ
Shift_JISX0213߂ꂽB2004N10ǉɔāAShift_JIS-2004
Ɩ̂ύXꂽB

IANAuShift_JISvƂOœo^ĂB

_ƌ_

_
1. SpƁAJIS X 0201Œ`锼pJi𓯈̃R[ȟn
   \łB
2. {ɂẮAMS-DOSœ{pR[hƂč̗pĈȗAp\
   RɂĈ|IȕyxȂ̕ɔׂăf[^
   \ (AWɂĂ͎x_JIS X 0208ŋK肳
   Ȃ@ˑ̊g{Ă邱ƂAgɊւĂ
   f[^\Ⴂ)B

_
1. pJî߂̗̈mۂ֌WAR[hV[NGX_ԍ́uv
   ̋؂ł͂ȂӏŕfĂB̂߁AR[hԍZŋ߂ۂ
   ώGȏKvłB
2. 2oCgڂ80(16)(ASCIĨR[ḧ)B̂߁A̋؂
   ɎԂBt@CAd̐擪當R[h肷ꍇ͂悢A
   납當R[h̔悤ƎvƁAň̏ꍇA擪܂łǂȂ
   ȂƂ邽߁AvO̍ɍHvKvɂȂB܂A̗
   Ɋ܂܂ꕔ̈̂̕߁A}`oCgEUC-JPAUTF-8ȂǂAv
   O~ÖB
3. JIS⏕\łȂB⏕̕Shift_JIS̃R[ho^
   ܂ȂB

2oCgڂ5CɂȂ肤邱Ƃɂ

Shift_JISł́Au\vu\vȂǈꕔ̎2oCgڂɁA5C(16)(Shift_JISł
LAASCIIȂǂł̓obNXbV)gpĂB̃vO~O
 (CAPerlABourne ShellȂǑ) ł́A5C(16)GXP[vƂ
BāA\[XR[h╶f[^̏ɂShift_JISz肵
ȂvO~Oł͖肪NB̖́A悤2oCgڂ
͈͂5C(16)܂Big5A܂ł͂邪GBKȂǂ̕R[hłB

܂A5C(16)ȊOɂĂގ̖肪邱ƂBƂ΁AUnix
MS-DOSȂǂ̃VF7C(16) (Shift_JISASCIIł̓o[eBJo[) ܂
(|A|A|A|A|A|A|Acc)t@CɎgp悤ƂƁA
pCvLƔFAɃt@C쐬ȂAǂݍ݂sǂ
Ȃ肷邱ƂB

݂łAVOoCgR[hΉ̃\tgEFAShift_JISŎgp
ƁAsȂǂ̓t@C̏Ȃǂɂ΂΂̖肪܂ƂB
sA2oCgڂ5C(16)̂ƂAߕƌĂсA̒ɂ
u\vu\vu\vu\vȂǈʂɎgppx̍[1]B

̖`Iȕ@ƂāA\[XR[hŜEUCR[hUTF-8Ȃ
ɕϊĂRpCs肷@B邢́u\\v
悤2oCgڂ̒OɃGXP[v5C(16)LqAߕ𕶎Ƃ
FȂǂ̕@(Perl Sjis\tgEFAȂ)Bŋ߂ł́A
̃vO~OꂪShift_JISɑΉ悤ɂȂ߁AShift_JIS܂
\[XR[hf[^Ă̖͋NȂȂÃ\tgEFA
Y𗘗pł͈ˑRA肪܂ƂB



pɂɌƂāAu\ȂvƂ񂪂̌f\tg
uȂvƉB

   \         
  8d5c 82ed 82c8 82a2
  obNXbVɂ5cƁA
  8d   82ed 82c8 82a2
             

uvƂ̂ƂŃfR[hē͐̕ɖ߂B܂l
Ɂu|\Evu|EvɉB 

   |    \   E
  8c7c 945c 8a45
  obNXbVɂ5cƁA
  8c7c 94   8a45
   |       E

  \ 2oCgڂ5C(16)ꗗ  (16i) ǂ݁EӖ 

  \   815C _bV
  \   835C Љ́uv
  \   845C L̃EB
  \/? 875C Windowsł̓[}9
            MacłGB(MKoCg)
  \   895C 킳B
  \   8A5C C
  \   8B5C ނB\
  \   8C5C BlB
  \   8D5C ܂B\
  \   8E5C JCRB{\
  \   8F5C 10B
  \   905C AB\
  \   915C AЁBu]v̈ẂB\
  \   925C B\y
  \   935C ͂B\t
  \   945C ̂B\
  \   955C 킷AЂ傤B\
  \   965C ΂AڂB\
  \   975C 炩߁AB\
  \   985C 낭B\
  \   995C ƁABuevّ̈̎
  \   9A5C B\
  \   9B5C B\a(ua̔񏑊)
  \   9C5C B퐶́uv̋
  \   9D5C B\
  \   9E5C Ȃ̕ʑ
  \   9F5C AA傤B
  \   E05C 炤AB
  \   E15C ӂAقB
  \   E25C ƂAւB
  \   E35C AB
  \   E45C łAB\
  \   E55C BaC\X
  \   E65C G̋
  \   E75C ̂̌Î
  \   E85C ΁B\()B
  \   E95C ܂B\
  \   EA5C oB̖B
  x   ED5C B
  x   EE5C 傭B
  \   FA5C 킽AB
  \   FB5C B

R[hԂɂ镶
Shift_JIS2oCgR[h̋Ԃ́A1oCg81(16)-9F(16)ȂтE0(16)-FC(16)A
2oCg40(16)-7E(16)Ȃт80(16)-FC(16)łBāA60~188=11280
A1oCgR[h158 (Xy[X܂݁ADEL͐)ł邽߁A
v11438ƂȂB

ȂAShift_JIS-2004ł́A2oCg11233A1oCg158̂߁A
v11391gpĂB

Shift_JISɂuVtgvƂ
ISO-2022-JP͎wV[PXŊƃAt@xbg؂ւ镄łB
܂AEUC-JP͕⏕ƔpJ^JiVOVtgňꎞIɐ؂ւĎg
łB̕ł́AeW̖ʂVtgR[hɂ
؂ւ(Vtg)ĂB

ȂAShift_JIŚwVtgxƂ͂̈Ӗł̃Vtgł͂ȂB܂Arbg
VtǵwVtgxłȂB́wVtgxƂ́A256~256̕ʂ̒ŕ
G"炷"ƂӖ́wVtgxłB

Shift_JISƋ_ԍ
Shift_JIS̑Ώۂɂ镶ZbǵAJIS X 0208łB̕
Wɂ́A_ԍƂTO݂B́A94~94̕\̍sƗ̔ԍ
̑głB

Shift_JISł́A8140(16)-FCFC(16)Ƃ悤ɁAJIS X 0208Ƃ͂܂
R[ȟnł邪AJIS X 0208vZɂό`̂ł邽߁A_ԍ
pĕ̃R[h|CgwƂBeɂẮAJIS X 0208
1`94ƓłBA@ˑł́AVtgJIS̕ԂtA
94̉ɂ120܂łgĂ邩̂悤ɈƂB95ȏ
́AISO/IEC 2022ɑJIS X 0208̍\ł݂͑Ȃ̂ŁA{͂B
x_Ǝ̔ȊTOłBȂAJIS X 0213̋Kïꕔł
Shift_JISX0213\ɂẮA1oCgF0(16)ȍ~2ʂ̕Ɋ蓖
ĂASƂ悤ȑ݂Ȃԍ͓oꂵȂB

ux-sjisvƁuMS_Kanjiv
ux-sjisvƁuMS_Kanjiv͂ƂɁAHTMLhLǵucharsetv̎w
uShift_JISv̕ʖƂĎgƂoB

ux-sjisvIANAɁuShift_JISvƂOo^OɁANetscape Navigator 2.0
ɂĎgĂGR[fBO̎wqłBꕔHTML\tg
ł̎wqgݍŎgĂB̂ߔF\ȃuEU邪A
uShift_JISvɏ邱Ƃ𐄏ĂB


=head1 ̃\tgEFAł "ShiftJIS"

̃\tgEFAł "ShiftJIS" ͏ĹuR[hԂɂ镶v
11438ׂĂ邱ƂڎwĂ܂B̂߂ɃASY2g
Ă܂B

  * ASY 1

    INebg̕т當oƂA1INebgR[h2INebgR[h
    ̋ʂ͑1INebgR[ĥ݂ōs܂B2INebg͍l܂B

    1INebgR[h:
      0x00-0x80, 0xA0-0xDF, 0xFD-0xFF

    2INebgR[h:
      1INebg  0x81-0x9F, 0xE0-0xEF, 0xF0-0xFC
      2INebg  0x00-0xFF (ׂ)

    s1INebgR[h:
      0x81-0x9F, 0xE0-0xFC
      * ̍ŏIINebg2INebgR[h̑1INebgƓꍇ

ȉɃR[h\fڂ܂B

        1INebgR[h\

   0 1 2 3 4 5 6 7 8 9 A B C D E F 
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 0|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x00-0x80
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 1|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 2|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 3|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 4|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 5|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 6|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 7|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 8|*| | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 9| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 A|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0xA0-0xDF
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 B|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 C|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 D|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 E| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 F| | | | | | | | | | | | | |*|*|*| 0xFD-0xFF
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+

                                 2INebgR[h\
            1INebg                                    2INebg


   0 1 2 3 4 5 6 7 8 9 A B C D E F                 0 1 2 3 4 5 6 7 8 9 A B C D E F 
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 0| | | | | | | | | | | | | | | | |              0|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x00-0xFF
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 1| | | | | | | | | | | | | | | | |              1|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 2| | | | | | | | | | | | | | | | |              2|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 3| | | | | | | | | | | | | | | | |              3|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 4| | | | | | | | | | | | | | | | |              4|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 5| | | | | | | | | | | | | | | | |              5|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 6| | | | | | | | | | | | | | | | |              6|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 7| | | | | | | | | | | | | | | | |              7|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 8| |*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x81-0x9F    8|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 9|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|              9|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 A| | | | | | | | | | | | | | | | |              A|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 B| | | | | | | | | | | | | | | | |              B|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 C| | | | | | | | | | | | | | | | |              C|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 D| | | | | | | | | | | | | | | | |              D|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 E|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0xE0-0xFC    E|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 F|*|*|*|*|*|*|*|*|*|*|*|*|*| | | |              F|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+


    *s* 1INebgR[h

̍ŏIINebg2INebgR[h̑1INebgƓꍇ

słĂꂽAIɍ폜邱Ƃ͂܂B
Ⴆ΁AEsjis::chop ͂̃INebgԂ܂B

   0 1 2 3 4 5 6 7 8 9 A B C D E F 
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 0| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 1| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 2| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 3| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 4| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 5| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 6| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 7| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 8| |M|M|M|M|M|M|M|M|M|M|M|M|M|M|M| 0x81-0x9F
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 9|M|M|M|M|M|M|M|M|M|M|M|M|M|M|M|M|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 A| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 B| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 C| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 D| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 E|M|M|M|M|M|M|M|M|M|M|M|M|M|M|M|M|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 F|M|M|M|M|M|M|M|M|M|M|M|M|M| | | |  0xE0-0xFC
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+


=head1 x_ SJIS R[hꗗ

http://home.m05.itscom.net/numa/cde/sjis-euc/sjis.html

 DEC PC                         0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 DEC WS                         0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Fujitsu TrueType font (PC)     0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Fujitsu FontCity font (PC)     0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Hitachi PC                     0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Hitachi WS                     0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 IBM                            0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 NEC Windows (PC)               0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 NEC DOS (PC)                   0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 SONY NEWS-OS                   0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Sun Wabi                       0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Unisys PC                      0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 HP Japan Japanese HP-15        0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 AT&T Japan                     0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Mitsubishi Electric FONTRUNNER 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Concurrent Japan               0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 Informix ASCII INFORMIX V6 ALS 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC), (0xFD)(0xA1-0xFE)(0xA1-0xFE)
 Oracle Oracle7 (Release 7.1.3) 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x00-0xFF)
 Sybase SQL Server, Open Server 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 
 {񏈗(ISBN 4-89052-708-7)
 
 Hewlett-Packard HP-15          0x00-0x7F, 0xA1-0xDF, (0x80-0xA0, 0xE0-0xFE)(0x21-0x7E, 0x80-0xFF)


  * ASY 2

    ASY 1 ɂւ炸Atr/// ɂ蕶͈̔͂w肳ꂽꍇ͈ȉ̕
    ݂̂LƂȂ܂B

    1INebgR[h:
      0x00-0x80, 0xA0-0xDF, 0xFD-0xFF

    2INebgR[h:
      1INebg  0x81-0x9F, 0xE0-0xEF, 0xF0-0xFC
      2INebg  0x40-0x7E, 0x80-0xFC

Ⴆ΁A[\x81\x00-\x82\xFF] Əꂽꍇ [\x81\x82][\x40-\x7E\x80-\xFC] 
Ӗ܂B

ȉɃR[h\fڂ܂B

        1INebgR[h\

   0 1 2 3 4 5 6 7 8 9 A B C D E F 
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 0|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x00-0x80
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 1|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 2|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 3|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 4|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 5|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 6|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 7|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 8|*| | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 9| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 A|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0xA0-0xDF
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 B|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 C|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 D|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 E| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 F| | | | | | | | | | | | | |*|*|*| 0xFD-0xFF
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+


                                 2INebgR[h\
            1INebg                                    2INebg

   0 1 2 3 4 5 6 7 8 9 A B C D E F                 0 1 2 3 4 5 6 7 8 9 A B C D E F 
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 0| | | | | | | | | | | | | | | | |              0| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 1| | | | | | | | | | | | | | | | |              1| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 2| | | | | | | | | | | | | | | | |              2| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 3| | | | | | | | | | | | | | | | |              3| | | | | | | | | | | | | | | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 4| | | | | | | | | | | | | | | | |              4|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x40-0x7E
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 5| | | | | | | | | | | | | | | | |              5|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 6| | | | | | | | | | | | | | | | |              6|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 7| | | | | | | | | | | | | | | | |              7|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 8| |*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x81-0x9F    8|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0x80-0xFC
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 9|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|              9|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 A| | | | | | | | | | | | | | | | |              A|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 B| | | | | | | | | | | | | | | | |              B|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 C| | | | | | | | | | | | | | | | |              C|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 D| | | | | | | | | | | | | | | | |              D|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 E|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*| 0xE0-0xFC    E|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|*|
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 F|*|*|*|*|*|*|*|*|*|*|*|*|*| | | |              F|*|*|*|*|*|*|*|*|*|*|*|*|*| | | |
  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+


=head1 ڕWƂĂ

vO~O Perl 3 VOLUME 1 (ISBN 4-87311-096-3)
15 Unicode Q

Unicode T|[g perl ɓȑÓAeq Zq́A2̃XJ[ϐɂ
ĕ\ꂽoCgׂĂ܂Bperl5.8 ȍ~Aeq ́A2̃oCgׂ
Ɠ UTF8 tOl܂B

ʓIɂ̕ύX́Aߋ̃XNvgƐVXNvg̊Ԃɑ傫ȍa܂B
͂◼҂̃XNvg̓R[h݂ɍėp邱Ƃł܂B܂V@
vO}ɕS邽߁AXNvgׂĒû͂܂܂
Ǝv܂B

V@ŖƂȂĂ邱Ƃ UTF8 tO͎ۂ̕̕ƈvȂ
łBōXNvg͂̃fobȎO UTF8 tOɂăfobOȂ
΂Ȃ܂B

Ő̂̕@ɖ߂ƂɂāAǂ̂悤ɉ̂ Programming Perl, 3rd ed.
(M vO~OPerl 3) 402y[Wxp܂傤B

zIɂ́Aȉ5̃S[悤ƍlĂ܂B

=over 2

=item * S[1

    ̃oCgw̃XNvǵAȑOẴoCgw̃f[^ɑ΂
    āAȑOƓlɓ삷ׂłB

     ShiftJIS oCgwł ASCII  JIS X 0201 Ƒg킹ėp
    ł悤݌vꂽƂɂāAłɒBĂ܂B

=item * S[2

    ̃oCgw̃XNvǵAɁA(邱ƂK؂ł)
    Vw̃f[^ɑ΂Ă삷悤ɂȂׂłB

    g݊֐ length, substr, index, rindex, pos Ȃǂ̒̕ʒu
    ͍̂܂łǂ1INebg 1 Ɛ܂B̕ɂĉ͉
    ܂B2INebgR[h1 length  2 ɂȂ܂B

    AXNvg̐K\́A}`oCĝ߂̃AJ[O
    LqKv܂AȂɑẴ\tgEFAs܂B

    S[1ƃS[2̓e}܂B

                                   GOAL#1  GOAL#2
                            (a)     (b)     (c)     (d)     (e)
         
          f[^        Old   Old   New   Old   New  
         
          XNvg    Old       Old           New      
         
          C^v^  Old               New              
         
          Old --- ̃oCgw
          New --- Vw

    f[^AXNvgAC^v^̐VEɊւāA (a)  (e) ܂ł
    g܂B̕ꂽɑ݂Ȃ Encode W[
    ̃\tgEFAAё݂Ă JPerl Ă݂܂傤B

                            (a)     (b)     (c)     (d)     (e)
                                           JPerl          Encode,Sjis
         
          f[^        Old   Old   New   Old   New  
         
          XNvg    Old       Old           New      
         
          C^v^  Old               New              
         
          Old --- ̃oCgw
          New --- Vw

    JPerl ƂĂDĂ闝R (c) ̈ʒuɂ邩łBȂ킿{ꏈ
    s߂ɃXNvgɓʂȋLqsKv܂B

    ΏƓIȂ̂ Encode W[₱̃\tgEFAɂ "use Sjis;" Lq
    ꍇłB̏ꍇ͐VȃXNvg̏Kv܂B

=item * S[3

    XNvǵAVw[hłAȑÕoCgw[hƓXs[
    hœ삷ׂłB

    ͖BāAȉ̎ԂKv́B

    (1) XNvgGXP[vāAoCgw Perl ň悤ɏ邽߂
     ԁBAꂽXNvg͕ۑł邽߁A񂩂͂̎ԂȂ
     Ƃ\łB

    (2) GXP[vꂽXNvg}`oCgAJ[OsȂA
     K\s鎞ԁB

    łɑ݂ ASCII f[^11INebgɃpbNĂ܂B
    f[^ƌ݊ۂȂ當𑝂₻ƂƁAISO-2022 ̂悤ɃGXP[
    vV[PXKvłAShiftJIS  UTF-8 ̂悤 "GXP[vrbg"
    KvɂȂ肵܂B̃GXP[v邽߁AȑOƓXs[
    hœ삷ׂłƂ͖̂ȖڕWƎv܂B

=item * S[4

    Perl ́AoCgw Perl ƕw Perl Ɏ}ꂹɁA1̌
    葱ׂłB

    JPerl  Perl 𕪊򂳂Ȃ悤ɂ邽߂ɁAC^v^𕪊򂳂܂B
    ł Perl RA`[̓C^v^̕]łȂ̂ł傤B

    oCgw Perl ͂łɃoCif[^Ƃł邽߁Aw
    Perl ʗĂō쐬Kv͂܂B̃\tgEFA͒PȂ Perl ̃Av
    P[VvOłAtB^vOƂč쐬Ă܂B
    {Iɂ perl słȂΓ삷ł傤B

    ɖ perl XNvgŉȂAPerl R~jeBT|[g
    邱Ƃł傤B

=item * S[5

    JPerl [U Perl  JPerl ێł悤ɂȂB

    ԂAĂƁB

=back

Programming Perl, 3rd ed. ꂽɂ́AUTF8 tO͐܂Ă炸APerl 
ȒPȎdȒPɂł悤ɐ݌vĂ܂B̃\tgEFÂ͓悤
vO~O񋟂܂B

=head1 Ql

 vO~OPerl 
 By Larry Wall, Tom Christiansen, Randal L. Schwartz, ߓ Ð 
 1997N12 s
 759y[W
 ISBN 4-900900-48-6
 http://www.oreilly.co.jp/out/pperl/index.htm

 vO~OPerl 3 VOLUME 1
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 756y[W
 ISBN 4-87311-096-3
 http://www.oreilly.co.jp/books/4873110963/

 vO~OPerl 3 VOLUME 2
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 680y[W
 ISBN 4-87311-097-1
 http://www.oreilly.co.jp/books/4873110971/

 PerlNbNubN 2 VOLUME 1
 By Tom Christiansen, Nathan Torkington, Shibuya Perl Mongers Ė, ЃhLgVXe 
 2004N09 s
 752y[W
 ISBN 4-87311-202-8
 http://www.oreilly.co.jp/books/4873112028/

 PerlNbNubN 2 VOLUME 2
 By Tom Christiansen, Nathan Torkington, Shibuya Perl Mongers Ė, ЃhLgVXe 
 2004N09 s
 464y[W
 ISBN 4-87311-203-6
 http://www.oreilly.co.jp/books/4873112036/

 PerlNCbNt@X
 By Stephen Spainhour, Ellen Siever, Nathan Patwardhan, ߓ Ð,  \ Ė
 2000N03 s
 784y[W
 ISBN 4-900900-72-9
 http://www.oreilly.co.jp/books/4900900729/

 ߂ĂPerl Win32VXe
 Randal L. Schwartz, Erik Olson, Tom Christiansen , Ln OY Ė, Ό q_ 
 1998N11 s
 348y[W
 ISBN 4-900900-79-6
 http://www.oreilly.co.jp/books/4900900796/

 ߂ĂPerl 5
 Randal L. Schwartz, Tom Phoenix, brian d foy 
 2009N1024 
 424y[W
 ISBN978-4-87311-427-9
 http://www.oreilly.co.jp/books/9784873114279/

 Perl\[XLbg - UNIX
 Futato, Irving, Jepson, Patwardhan, Siever , CG[[x R{ _ 
 ISBN4-900900-65-6

 {񏈗
 Understanding Japanese Information Processing
 By Ken Lunde, tՐ, ؕ 
 1995N8 s
 496y[W
 ISBN 4-89052-708-7

 CJKV؉z񏈗
 Chinese, Japanese, Korean & Vietnamese Computing
 By Ken Lunde,  , t  
 2002N12 s
 1172y[W
 ISBN 4-87311-108-0
 http://www.oreilly.co.jp/books/4873111080/

 ڐ K\ 2
 By Jeffrey E. F. Friedl, ca  
 2003N05 s
 464y[W
 ISBN 4-87311-130-7
 http://www.oreilly.co.jp/books/4873111307/

 ڐ K\ 3
 By Jeffrey E. F. Friedl, ЃOe[^ O 
 2008N04 s
 528y[W
 ISBN 978-4-87311-359-3
 http://www.oreilly.co.jp/books/9784873113593/

 PerlvO~O
 Larry Wall, Randal L.Schwartz, ߓ Ð 
 1993N2s
 ISBN 4-89052-384-7
 http://www.context.co.jp/~cond/books/old-books.html

 JIST
 Ŗki Ғ
 1456 
 ISBN 4-542-20129-5
 http://www.webstore.jsa.or.jp/lib/lib.asp?fn=/manual/mnl01_12.htm

 UNIX MAGAZINE
 1993N8
 172y[W
 T1008901080816 G08901-8
 http://ascii.asciimw.jp/books/magazines/unix.shtml

 ֘A\tgEFA
 http://search.cpan.org/dist/Big5Plus/
 http://search.cpan.org/dist/EUCJP/
 http://search.cpan.org/dist/GB18030/
 http://search.cpan.org/dist/HP15/
 http://search.cpan.org/dist/INFORMIXV6ALS/
 http://search.cpan.org/dist/Sjis/
 http://search.cpan.org/dist/UHC/
 http://search.cpan.org/dist/UTF2/
 http://search.cpan.org/dist/jacode/

=head1 ӎ

̃\tgEFÁAȉ̕X̍쐬\tgEFAѕ̂ɂ쐬
܂BSĂ̕Ɋӂ܂B

 R Ǒ, VtgJIS̃fUC̘b
 ttp://furukawablog.spaces.live.com/Blog/cns!1pmWgsL289nm7Shn7cS0jHzA!2225.entry
 (擪 'h' tăANZXĂ)

 Larry Wall, Perl
 http://www.perl.org/

 ̑ a, jcode.pl
 ftp://ftp.iij.ad.jp/pub/IIJ/dist/utashiro/perl/

 Jeffrey E. F. Friedl, Mastering Regular Expressions
 http://www.oreilly.com/catalog/regex/index.html

 A ms, Shift-JISeLXg𐳂
 http://homepage1.nifty.com/nomenclator/perl/shiftjis.htm

 ܂ 䂫Ђ낳, Ruby on Perl(s)
 http://www.rubyist.net/~matz/slides/yapc2006/

  av, jperl[U[̂߂
 http://homepage1.nifty.com/kazuf/jperl.html

 a G, WindowsPerl 5.8/5.10gȂ
 http://www.aritia.org/hizumi/perl/perlwin.html

 ˖{ q, Perl/Windowsł̃t@CpX
 http://digit.que.ne.jp/work/wiki.cgi?Perl%E3%83%A1%E3%83%A2%2FWindows%E3%81%A7%E3%81%AE%E3%83%95%E3%82%A1%E3%82%A4%E3%83%AB%E3%83%91%E3%82%B9

 chaichanPaPa, VtgJIS̃t@CɃ}b`Ă݂
 http://d.hatena.ne.jp/chaichanPaPa/20080802/1217660826

  Iv, Jperl
 http://homepage2.nifty.com/kipp/perl/jperl/

 n , Jperl
 http://search.cpan.org/~watanabe/
 ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt

  e, Encode W[
 http://search.cpan.org/dist/Encode/

 Juerd, Perl Unicode Advice
 http://juerd.nl/site.plp/perluniadvice

 daily dayflower, 2008-06-25 perluniadvice
 http://d.hatena.ne.jp/dayflower/20080625/1214374293

 Tokyo-pm ۑ
 http://mail.pm.org/pipermail/tokyo-pm/
 http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
 http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html

 ruby-list
 http://blade.nagaokaut.ac.jp/ruby/ruby-list/index.shtml
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2440
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2446
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2569
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/9427
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/9431
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10500
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10501
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10502
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12385
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12392
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12393
 http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/19156

=cut

